===========
Meta
===========

The following methods are available under the `expr.meta` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.meta.eq
    Expr.meta.has_multiple_outputs
    Expr.meta.is_regex_projection
    Expr.meta.ne
    Expr.meta.output_name
    Expr.meta.pop
    Expr.meta.tree_format
    Expr.meta.root_names
    Expr.meta.undo_aliases
    Expr.meta.write_json
